@@ -30,6 +30,9 @@
  * priorities of individual Clips. Two layers should not have the
  * same priority within a given timeline.
  */
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
 
 #include "ges-internal.h"
 #include "ges-layer.h"
@@ -39,11 +42,6 @@
 static void ges_meta_container_interface_init
     (GESMetaContainerInterface * iface);
 
-G_DEFINE_TYPE_WITH_CODE (GESLayer, ges_layer,
-    G_TYPE_INITIALLY_UNOWNED, G_IMPLEMENT_INTERFACE (GES_TYPE_EXTRACTABLE, NULL)
-    G_IMPLEMENT_INTERFACE (GES_TYPE_META_CONTAINER,
-        ges_meta_container_interface_init));
-
 struct _GESLayerPrivate
 {
   /*< private > */
@@ -78,6 +76,12 @@ enum
 
 static guint ges_layer_signals[LAST_SIGNAL] = { 0 };
 
+G_DEFINE_TYPE_WITH_CODE (GESLayer, ges_layer,
+    G_TYPE_INITIALLY_UNOWNED, G_IMPLEMENT_INTERFACE (GES_TYPE_EXTRACTABLE, NULL)
+    G_ADD_PRIVATE (GESLayer)
+    G_IMPLEMENT_INTERFACE (GES_TYPE_META_CONTAINER,
+        ges_meta_container_interface_init));
+
 /* GObject standard vmethods */
 static void
 ges_layer_get_property (GObject * object, guint property_id,
@@ -105,7 +109,8 @@ ges_layer_set_property (GObject * object, guint property_id,
 
   switch (property_id) {
     case PROP_PRIORITY:
-      ges_layer_set_priority (layer, g_value_get_uint (value));
+      GST_FIXME ("Deprecated, use ges_timeline_move_layer instead");
+      layer_set_priority (layer, g_value_get_uint (value), FALSE);
       break;
     case PROP_AUTO_TRANSITION:
       ges_layer_set_auto_transition (layer, g_value_get_boolean (value));
@@ -149,8 +154,6 @@ ges_layer_class_init (GESLayerClass * klass)
 {
   GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
-  g_type_class_add_private (klass, sizeof (GESLayerPrivate));
-
   object_class->get_property = ges_layer_get_property;
   object_class->set_property = ges_layer_set_property;
   object_class->dispose = ges_layer_dispose;
@@ -165,6 +168,10 @@ ges_layer_class_init (GESLayerClass * klass)
    *
    * Note that the timeline needs to be commited (with #ges_timeline_commit)
    * for the change to be taken into account.
+   *
+   * Deprecated:1.16.0: use #ges_timeline_move_layer instead. This deprecation means
+   * that you will not need to handle layer priorities at all yourself, GES
+   * will make sure there is never 'gaps' between layer priorities.
    */
   g_object_class_install_property (object_class, PROP_PRIORITY,
       g_param_spec_uint ("priority", "Priority",
@@ -208,8 +215,7 @@ ges_layer_class_init (GESLayerClass * klass)
 static void
 ges_layer_init (GESLayer * self)
 {
-  self->priv = G_TYPE_INSTANCE_GET_PRIVATE (self,
-      GES_TYPE_LAYER, GESLayerPrivate);
+  self->priv = ges_layer_get_instance_private (self);
 
   self->priv->priority = 0;
   self->priv->auto_transition = FALSE;
@@ -228,9 +234,6 @@ ges_layer_resync_priorities_by_type (GESLayer * layer,
   GList *tmp;
   GESTimelineElement *element;
 
-  layer->priv->clips_start =
-      g_list_sort (layer->priv->clips_start,
-      (GCompareFunc) element_start_compare);
   for (tmp = layer->priv->clips_start; tmp; tmp = tmp->next) {
 
     element = GES_TIMELINE_ELEMENT (tmp->data);
@@ -285,6 +288,23 @@ ges_layer_resync_priorities (GESLayer * layer)
   return TRUE;
 }
 
+void
+layer_set_priority (GESLayer * layer, guint priority, gboolean emit)
+{
+  GST_DEBUG ("layer:%p, priority:%d", layer, priority);
+
+  if (priority != layer->priv->priority) {
+    layer->priv->priority = priority;
+    layer->min_nle_priority = (priority * LAYER_HEIGHT) + MIN_NLE_PRIO;
+    layer->max_nle_priority = ((priority + 1) * LAYER_HEIGHT) + MIN_NLE_PRIO;
+
+    ges_layer_resync_priorities (layer);
+  }
+
+  if (emit)
+    g_object_notify (G_OBJECT (layer), "priority");
+}
+
 static void
 new_asset_cb (GESAsset * source, GAsyncResult * res, NewAssetUData * udata)
 {
@@ -416,23 +436,19 @@ ges_layer_remove_clip (GESLayer * layer, GESClip * clip)
  *
  * Sets the layer to the given @priority. See the documentation of the
  * priority property for more information.
+ *
+ * Deprecated:1.16.0: use #ges_timeline_move_layer instead. This deprecation means
+ * that you will not need to handle layer priorities at all yourself, GES
+ * will make sure there is never 'gaps' between layer priorities.
  */
 void
 ges_layer_set_priority (GESLayer * layer, guint priority)
 {
   g_return_if_fail (GES_IS_LAYER (layer));
 
-  GST_DEBUG ("layer:%p, priority:%d", layer, priority);
+  GST_FIXME ("Deprecated, use ges_timeline_move_layer instead");
 
-  if (priority != layer->priv->priority) {
-    layer->priv->priority = priority;
-    layer->min_nle_priority = (priority * LAYER_HEIGHT) + MIN_NLE_PRIO;
-    layer->max_nle_priority = ((priority + 1) * LAYER_HEIGHT) + MIN_NLE_PRIO;
-
-    ges_layer_resync_priorities (layer);
-  }
-
-  g_object_notify (G_OBJECT (layer), "priority");
+  layer_set_priority (layer, priority, TRUE);
 }
 
 /**
@@ -767,9 +783,6 @@ ges_layer_get_clips_in_interval (GESLayer * layer, GstClockTime start,
 
   g_return_val_if_fail (GES_IS_LAYER (layer), NULL);
 
-  layer->priv->clips_start =
-      g_list_sort (layer->priv->clips_start,
-      (GCompareFunc) element_start_compare);
   for (tmp = layer->priv->clips_start; tmp; tmp = tmp->next) {
     clip_intersects = FALSE;
     clip_start = ges_timeline_element_get_start (tmp->data);
