@@ -27,6 +27,9 @@
  * in a simple fashion.
  * Its usage is inspired by the 'playbin' element from gst-plugins-base.
  */
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
 
 #include <gst/gst.h>
 #include <gst/video/videooverlay.h>
@@ -154,7 +157,7 @@ video_overlay_init (gpointer g_iface, gpointer g_iface_data)
 }
 
 G_DEFINE_TYPE_WITH_CODE (GESPipeline, ges_pipeline,
-    GST_TYPE_PIPELINE,
+    GST_TYPE_PIPELINE, G_ADD_PRIVATE (GESPipeline)
     G_IMPLEMENT_INTERFACE (GST_TYPE_VIDEO_OVERLAY, video_overlay_init));
 
 static void
@@ -275,6 +278,7 @@ ges_pipeline_dispose (GObject * object)
         _timeline_track_added_cb, self);
     g_signal_handlers_disconnect_by_func (self->priv->timeline,
         _timeline_track_removed_cb, self);
+    gst_element_set_state (GST_ELEMENT (self->priv->timeline), GST_STATE_NULL);
   }
 
   G_OBJECT_CLASS (ges_pipeline_parent_class)->dispose (object);
@@ -286,8 +290,6 @@ ges_pipeline_class_init (GESPipelineClass * klass)
   GObjectClass *object_class = G_OBJECT_CLASS (klass);
   GstElementClass *element_class = GST_ELEMENT_CLASS (klass);
 
-  g_type_class_add_private (klass, sizeof (GESPipelinePrivate));
-
   GST_DEBUG_CATEGORY_INIT (ges_pipeline_debug, "gespipeline",
       GST_DEBUG_FG_YELLOW, "ges pipeline");
 
@@ -371,8 +373,7 @@ static void
 ges_pipeline_init (GESPipeline * self)
 {
   GST_INFO_OBJECT (self, "Creating new 'playsink'");
-  self->priv = G_TYPE_INSTANCE_GET_PRIVATE (self,
-      GES_TYPE_PIPELINE, GESPipelinePrivate);
+  self->priv = ges_pipeline_get_instance_private (self);
   self->priv->valid_thread = g_thread_self ();
 
   self->priv->playsink =
