@@ -44,6 +44,10 @@
  * a set of signals. Also it handles problem such as missing files/missing
  * #GstElement and lets you try to recover from those.
  */
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include "ges.h"
 #include "ges-internal.h"
 
@@ -53,8 +57,6 @@ static GHashTable *tried_uris = NULL;
 /* TODO We should rely on both extractable_type and @id to identify
  * a Asset, not only @id
  */
-G_DEFINE_TYPE (GESProject, ges_project, GES_TYPE_ASSET);
-
 struct _GESProjectPrivate
 {
   GHashTable *assets;
@@ -87,6 +89,8 @@ enum
   LAST_SIGNAL
 };
 
+G_DEFINE_TYPE_WITH_PRIVATE (GESProject, ges_project, GES_TYPE_ASSET);
+
 static guint _signals[LAST_SIGNAL] = { 0 };
 
 static guint nb_projects = 0;
@@ -422,8 +426,6 @@ ges_project_class_init (GESProjectClass * klass)
 {
   GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
-  g_type_class_add_private (klass, sizeof (GESProjectPrivate));
-
   klass->asset_added = NULL;
   klass->missing_uri = ges_missing_uri_default;
   klass->loading_error = NULL;
@@ -545,8 +547,7 @@ static void
 ges_project_init (GESProject * project)
 {
   GESProjectPrivate *priv = project->priv =
-      G_TYPE_INSTANCE_GET_PRIVATE (project,
-      GES_TYPE_PROJECT, GESProjectPrivate);
+      ges_project_get_instance_private (project);
 
   priv->uri = NULL;
   priv->formatters = NULL;
@@ -788,13 +789,15 @@ ges_project_create_asset_sync (GESProject * project, const gchar * id,
       GESAsset *tmpasset;
 
       tmpasset = ges_asset_cache_lookup (extractable_type, id);
-      g_signal_emit (project, _signals[ASSET_LOADING_SIGNAL], 0, tmpasset);
-      g_signal_emit (project, _signals[ERROR_LOADING_ASSET], 0, *error, id,
-          extractable_type);
       possible_id = ges_project_try_updating_id (project, tmpasset, *error);
 
-      if (possible_id == NULL)
+      if (possible_id == NULL) {
+        g_signal_emit (project, _signals[ASSET_LOADING_SIGNAL], 0, tmpasset);
+        g_signal_emit (project, _signals[ERROR_LOADING_ASSET], 0, *error, id,
+            extractable_type);
         return NULL;
+      }
+
 
       g_clear_error (error);
 
