@@ -16,12 +16,100 @@
  * You should have received a copy of the GNU Lesser General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.";
  */
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
 
 #include "gstframepositioner.h"
 #include "ges-types.h"
 #include "ges-internal.h"
 #include "ges-smart-video-mixer.h"
 
+#define GES_TYPE_SMART_MIXER_PAD             (ges_smart_mixer_pad_get_type ())
+#define GES_SMART_MIXER_PAD(obj)             (G_TYPE_CHECK_INSTANCE_CAST ((obj), GES_TYPE_SMART_MIXER_PAD, GESSmartMixerPad))
+#define GES_SMART_MIXER_PAD_CLASS(klass)     (G_TYPE_CHECK_CLASS_CAST ((klass), GES_TYPE_SMART_MIXER_PAD, GESSmartMixerPadClass))
+#define GES_IS_SMART_MIXER_PAD(obj)          (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GES_TYPE_SMART_MIXER_PAD))
+#define GES_IS_SMART_MIXER_PAD_CLASS(klass)  (G_TYPE_CHECK_CLASS_TYPE ((klass), GES_TYPE_SMART_MIXER_PAD))
+#define GES_SMART_MIXER_PAD_GET_CLASS(obj)   (G_TYPE_INSTANCE_GET_CLASS ((obj), GES_TYPE_SMART_MIXER_PAD, GESSmartMixerPadClass))
+
+typedef struct _GESSmartMixerPad GESSmartMixerPad;
+typedef struct _GESSmartMixerPadClass GESSmartMixerPadClass;
+
+struct _GESSmartMixerPad
+{
+  GstGhostPad parent;
+
+  gdouble alpha;
+  GstSegment segment;
+};
+
+struct _GESSmartMixerPadClass
+{
+  GstGhostPadClass parent_class;
+};
+
+enum
+{
+  PROP_PAD_0,
+  PROP_PAD_ALPHA,
+};
+
+static GType ges_smart_mixer_pad_get_type (void);
+
+G_DEFINE_TYPE (GESSmartMixerPad, ges_smart_mixer_pad, GST_TYPE_GHOST_PAD);
+
+static void
+ges_smart_mixer_pad_get_property (GObject * object, guint prop_id,
+    GValue * value, GParamSpec * pspec)
+{
+  GESSmartMixerPad *pad = GES_SMART_MIXER_PAD (object);
+
+  switch (prop_id) {
+    case PROP_PAD_ALPHA:
+      g_value_set_double (value, pad->alpha);
+      break;
+    default:
+      G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
+      break;
+  }
+}
+
+static void
+ges_smart_mixer_pad_set_property (GObject * object, guint prop_id,
+    const GValue * value, GParamSpec * pspec)
+{
+  GESSmartMixerPad *pad = GES_SMART_MIXER_PAD (object);
+
+  switch (prop_id) {
+    case PROP_PAD_ALPHA:
+      pad->alpha = g_value_get_double (value);
+      break;
+    default:
+      G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
+      break;
+  }
+}
+
+static void
+ges_smart_mixer_pad_init (GESSmartMixerPad * self)
+{
+  gst_segment_init (&self->segment, GST_FORMAT_UNDEFINED);
+}
+
+static void
+ges_smart_mixer_pad_class_init (GESSmartMixerPadClass * klass)
+{
+  GObjectClass *gobject_class = (GObjectClass *) klass;
+
+  gobject_class->get_property = ges_smart_mixer_pad_get_property;
+  gobject_class->set_property = ges_smart_mixer_pad_set_property;
+
+  g_object_class_install_property (gobject_class, PROP_PAD_ALPHA,
+      g_param_spec_double ("alpha", "Alpha", "Alpha of the picture", 0.0, 1.0,
+          1.0,
+          G_PARAM_READWRITE | GST_PARAM_CONTROLLABLE | G_PARAM_STATIC_STRINGS));
+}
+
 G_DEFINE_TYPE (GESSmartMixer, ges_smart_mixer, GST_TYPE_BIN);
 
 #define GET_LOCK(obj) (&((GESSmartMixer*)(obj))->lock)
@@ -88,9 +176,10 @@ ges_smart_mixer_get_mixer_pad (GESSmartMixer * self, GstPad ** mixerpad)
    added in the video sources' bin */
 static GstPadProbeReturn
 parse_metadata (GstPad * mixer_pad, GstPadProbeInfo * info,
-    GESSmartMixer * self)
+    GESSmartMixerPad * ghost)
 {
   GstFramePositionerMeta *meta;
+  GESSmartMixer *self = GES_SMART_MIXER (GST_OBJECT_PARENT (ghost));
 
   meta =
       (GstFramePositionerMeta *) gst_buffer_get_meta ((GstBuffer *) info->data,
@@ -105,7 +194,33 @@ parse_metadata (GstPad * mixer_pad, GstPadProbeInfo * info,
     g_object_set (mixer_pad, "alpha", meta->alpha,
         "zorder", meta->zorder, NULL);
   } else {
-    g_object_set (mixer_pad, "alpha", meta->alpha, NULL);
+    gint64 stream_time;
+    gdouble transalpha;
+
+    GST_OBJECT_LOCK (ghost);
+    if (ghost->segment.format == GST_FORMAT_UNDEFINED) {
+      const GstSegment *seg;
+      GstEvent *segev;
+
+      GST_OBJECT_UNLOCK (ghost);
+      segev = gst_pad_get_sticky_event (GST_PAD (ghost), GST_EVENT_SEGMENT, 0);
+      gst_event_parse_segment (segev, &seg);
+      gst_event_unref (segev);
+      GST_OBJECT_LOCK (ghost);
+
+      ghost->segment = *seg;
+
+    }
+
+    stream_time = gst_segment_to_stream_time (&ghost->segment, GST_FORMAT_TIME,
+        GST_BUFFER_PTS (info->data));
+    GST_OBJECT_UNLOCK (ghost);
+
+    if (GST_CLOCK_TIME_IS_VALID (stream_time))
+      gst_object_sync_values (GST_OBJECT (ghost), stream_time);
+
+    g_object_get (ghost, "alpha", &transalpha, NULL);
+    g_object_set (mixer_pad, "alpha", meta->alpha * transalpha, NULL);
   }
 
   g_object_set (mixer_pad, "xpos", meta->posx, "ypos",
@@ -152,7 +267,10 @@ _request_new_pad (GstElement * element, GstPadTemplate * templ,
   gst_element_add_pad (GST_ELEMENT (infos->bin), tmpghost);
 
   gst_bin_add (GST_BIN (self), infos->bin);
-  ghost = gst_ghost_pad_new (NULL, tmpghost);
+  ghost = g_object_new (ges_smart_mixer_pad_get_type (), "name", name,
+      "direction", GST_PAD_DIRECTION (tmpghost), NULL);
+  gst_ghost_pad_construct (GST_GHOST_PAD (ghost));
+  gst_ghost_pad_set_target (GST_GHOST_PAD_CAST (ghost), tmpghost);
   gst_pad_set_active (ghost, TRUE);
   if (!gst_element_add_pad (GST_ELEMENT (self), ghost))
     goto could_not_add;
@@ -166,7 +284,7 @@ _request_new_pad (GstElement * element, GstPadTemplate * templ,
 
   infos->probe_id =
       gst_pad_add_probe (infos->mixer_pad, GST_PAD_PROBE_TYPE_BUFFER,
-      (GstPadProbeCallback) parse_metadata, self, NULL);
+      (GstPadProbeCallback) parse_metadata, ghost, NULL);
 
   LOCK (self);
   g_hash_table_insert (self->pads_infos, ghost, infos);
@@ -232,7 +350,6 @@ static void
 ges_smart_mixer_constructed (GObject * obj)
 {
   GstPad *pad;
-  GstElement *identity;
 
   GESSmartMixer *self = GES_SMART_MIXER (obj);
   gchar *cname = g_strdup_printf ("%s-compositor", GST_OBJECT_NAME (self));
@@ -241,15 +358,9 @@ ges_smart_mixer_constructed (GObject * obj)
       gst_element_factory_create (ges_get_compositor_factory (), cname);
   g_free (cname);
   g_object_set (self->mixer, "background", 1, NULL);
+  gst_bin_add (GST_BIN (self), self->mixer);
 
-  identity = gst_element_factory_make ("identity", NULL);
-  g_object_set (identity, "drop-allocation", TRUE, NULL);
-  g_assert (identity);
-
-  gst_bin_add_many (GST_BIN (self), self->mixer, identity, NULL);
-  gst_element_link (self->mixer, identity);
-
-  pad = gst_element_get_static_pad (identity, "src");
+  pad = gst_element_get_static_pad (self->mixer, "src");
   self->srcpad = gst_ghost_pad_new ("src", pad);
   gst_pad_set_active (self->srcpad, TRUE);
   gst_object_unref (pad);
