@@ -17,6 +17,9 @@
  * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  */
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
 
 #include "ges-structure-parser.h"
 
@@ -128,6 +131,8 @@ ges_structure_parser_parse_symbol (GESStructureParser * self,
     ges_structure_parser_parse_string (self, "effect, bin-description=", TRUE);
   else if (!g_ascii_strncasecmp (symbol, "transition", 10))
     ges_structure_parser_parse_string (self, "transition, type=", TRUE);
+  else if (!g_ascii_strncasecmp (symbol, "title", 5))
+    ges_structure_parser_parse_string (self, "title, text=(string)", TRUE);
 }
 
 void
