@@ -23,6 +23,9 @@
  * @title: GESVideoTransition
  * @short_description: implements video crossfade transition
  */
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
 
 #include <ges/ges.h>
 #include "ges-internal.h"
@@ -31,7 +34,6 @@
 #include <gst/controller/gstdirectcontrolbinding.h>
 
 #define parent_class ges_video_transition_parent_class
-G_DEFINE_TYPE (GESVideoTransition, ges_video_transition, GES_TYPE_TRANSITION);
 
 static inline void
 ges_video_transition_set_border_internal (GESVideoTransition * self,
@@ -50,7 +52,8 @@ struct _GESVideoTransitionPrivate
   GESVideoStandardTransitionType pending_type;
 
   /* these enable video interpolation */
-  GstTimedValueControlSource *crossfade_control_source;
+  GstTimedValueControlSource *fade_in_control_source;
+  GstTimedValueControlSource *fade_out_control_source;
   GstTimedValueControlSource *smpte_control_source;
 
   /* so we can support changing between wipes */
@@ -83,6 +86,9 @@ enum
 
 static GParamSpec *properties[PROP_LAST];
 
+G_DEFINE_TYPE_WITH_PRIVATE (GESVideoTransition, ges_video_transition,
+    GES_TYPE_TRANSITION);
+
 #define fast_element_link(a,b) gst_element_link_pads_full((a),"src",(b),"sink",GST_PAD_LINK_CHECK_NOTHING)
 
 static GObject *link_element_to_mixer_with_smpte (GstBin * bin,
@@ -134,8 +140,6 @@ ges_video_transition_class_init (GESVideoTransitionClass * klass)
   GESTrackElementClass *toclass;
   GESTimelineElementClass *element_class = GES_TIMELINE_ELEMENT_CLASS (klass);
 
-  g_type_class_add_private (klass, sizeof (GESVideoTransitionPrivate));
-
   object_class = G_OBJECT_CLASS (klass);
 
   object_class->get_property = ges_video_transition_get_property;
@@ -189,10 +193,10 @@ ges_video_transition_class_init (GESVideoTransitionClass * klass)
 static void
 ges_video_transition_init (GESVideoTransition * self)
 {
-  self->priv = G_TYPE_INSTANCE_GET_PRIVATE (self,
-      GES_TYPE_VIDEO_TRANSITION, GESVideoTransitionPrivate);
+  self->priv = ges_video_transition_get_instance_private (self);
 
-  self->priv->crossfade_control_source = NULL;
+  self->priv->fade_in_control_source = NULL;
+  self->priv->fade_out_control_source = NULL;
   self->priv->smpte_control_source = NULL;
   self->priv->smpte = NULL;
   self->priv->mixer_sink = NULL;
@@ -230,9 +234,14 @@ ges_video_transition_dispose (GObject * object)
 
   GST_DEBUG ("disposing");
 
-  if (priv->crossfade_control_source) {
-    gst_object_unref (priv->crossfade_control_source);
-    priv->crossfade_control_source = NULL;
+  if (priv->fade_in_control_source) {
+    gst_object_unref (priv->fade_in_control_source);
+    priv->fade_in_control_source = NULL;
+  }
+
+  if (priv->fade_out_control_source) {
+    gst_object_unref (priv->fade_out_control_source);
+    priv->fade_out_control_source = NULL;
   }
 
   if (priv->smpte_control_source) {
@@ -300,17 +309,14 @@ ges_video_transition_set_property (GObject * object,
 
 static GstTimedValueControlSource *
 set_interpolation (GstObject * element, GESVideoTransitionPrivate * priv,
-    const gchar * propname, gboolean absolute)
+    const gchar * propname)
 {
   GstControlSource *control_source;
 
   g_object_set (element, propname, (gfloat) 0.0, NULL);
 
   control_source = gst_interpolation_control_source_new ();
-
   gst_object_add_control_binding (GST_OBJECT (element),
-      absolute ? gst_direct_control_binding_new_absolute (GST_OBJECT (element),
-          propname, control_source) :
       gst_direct_control_binding_new (GST_OBJECT (element), propname,
           control_source));
   g_object_set (control_source, "mode", GST_INTERPOLATION_MODE_LINEAR, NULL);
@@ -334,14 +340,8 @@ ges_video_transition_create_element (GESTrackElement * object)
 
   topbin = gst_bin_new ("transition-bin");
 
-  iconva =
-      gst_parse_bin_from_description
-      ("videoconvert ! capsfilter caps=\"video/x-raw,format=BGRA\"", TRUE,
-      NULL);
-  iconvb =
-      gst_parse_bin_from_description
-      ("videoconvert ! capsfilter caps=\"video/x-raw,format=BGRA\"", TRUE,
-      NULL);
+  iconva = gst_element_factory_make ("videoconvert", "tr-csp-a");
+  iconvb = gst_element_factory_make ("videoconvert", "tr-csp-b");
   priv->positioner =
       gst_element_factory_make ("framepositioner", "frame_tagger");
   g_object_set (priv->positioner, "zorder",
@@ -351,11 +351,9 @@ ges_video_transition_create_element (GESTrackElement * object)
   gst_bin_add_many (GST_BIN (topbin), iconva, iconvb, priv->positioner,
       oconv, NULL);
 
-  mixer =
-      g_object_new (GES_TYPE_SMART_MIXER, "name",
-      GES_TIMELINE_ELEMENT_NAME (self), NULL);
-  g_object_set (GES_SMART_MIXER (mixer)->mixer, "background", 3, NULL);
+  mixer = ges_smart_mixer_new (NULL);
   GES_SMART_MIXER (mixer)->disable_zorder_alpha = TRUE;
+  g_object_set (GES_SMART_MIXER (mixer)->mixer, "background", 3, NULL); /* transparent */
   gst_bin_add (GST_BIN (topbin), mixer);
 
   priv->mixer_sinka =
@@ -367,7 +365,9 @@ ges_video_transition_create_element (GESTrackElement * object)
       mixer, GES_VIDEO_STANDARD_TRANSITION_TYPE_BAR_WIPE_LR, &priv->smpte,
       priv, &priv->mixer_ghostb);
   g_object_set (priv->mixer_sinka, "zorder", 0, NULL);
+  gst_util_set_object_arg (G_OBJECT (priv->mixer_sinka), "operator", "source");
   g_object_set (priv->mixer_sinkb, "zorder", 1, NULL);
+  gst_util_set_object_arg (G_OBJECT (priv->mixer_sinkb), "operator", "add");
 
   fast_element_link (mixer, priv->positioner);
   fast_element_link (priv->positioner, oconv);
@@ -390,11 +390,12 @@ ges_video_transition_create_element (GESTrackElement * object)
 
   /* set up interpolation */
 
-  priv->crossfade_control_source =
-      set_interpolation (GST_OBJECT (priv->mixer_sinka), priv,
-      "crossfade-ratio", TRUE);
+  priv->fade_out_control_source =
+      set_interpolation (GST_OBJECT (priv->mixer_ghosta), priv, "alpha");
+  priv->fade_in_control_source =
+      set_interpolation (GST_OBJECT (priv->mixer_ghostb), priv, "alpha");
   priv->smpte_control_source =
-      set_interpolation (GST_OBJECT (priv->smpte), priv, "position", FALSE);
+      set_interpolation (GST_OBJECT (priv->smpte), priv, "position");
   priv->mixer = gst_object_ref (mixer);
 
   if (priv->pending_type)
@@ -462,12 +463,16 @@ ges_video_transition_update_control_sources (GESVideoTransition * self,
   GST_LOG ("updating controller");
   if (type == GES_VIDEO_STANDARD_TRANSITION_TYPE_CROSSFADE) {
     ges_video_transition_update_control_source
-        (priv->crossfade_control_source, duration, 1.0, 0.0);
+        (priv->fade_in_control_source, duration, 0.0, 1.0);
+    ges_video_transition_update_control_source
+        (priv->fade_out_control_source, duration, 1.0, 0.0);
     ges_video_transition_update_control_source (priv->smpte_control_source,
         duration, 0.0, 0.0);
   } else {
     ges_video_transition_update_control_source
-        (priv->crossfade_control_source, duration, -1.0, -1.0);
+        (priv->fade_in_control_source, duration, 1.0, 1.0);
+    ges_video_transition_update_control_source
+        (priv->fade_out_control_source, duration, 1.0, 1.0);
     ges_video_transition_update_control_source (priv->smpte_control_source,
         duration, 1.0, 0.0);
   }
