@@ -35,6 +35,10 @@
 #include "ges/gstframepositioner.h"
 #include "ges-internal.h"
 
+#ifndef DISABLE_XPTV
+#include <ges/ges-pitivi-formatter.h>
+#endif
+
 #define GES_GNONLIN_VERSION_NEEDED_MAJOR 1
 #define GES_GNONLIN_VERSION_NEEDED_MINOR 2
 #define GES_GNONLIN_VERSION_NEEDED_MICRO 0
@@ -61,6 +65,7 @@ ges_init_post (GOptionContext * context, GOptionGroup * group, gpointer data,
     GError ** error)
 {
   GESUriClipAssetClass *uriasset_klass = NULL;
+  GstElementFactory *nlecomposition_factory = NULL;
 
   if (ges_initialized) {
     GST_DEBUG ("already initialized ges");
@@ -74,6 +79,19 @@ ges_init_post (GOptionContext * context, GOptionGroup * group, gpointer data,
   if (!uriasset_klass->sync_discoverer)
     goto failed;
 
+  nlecomposition_factory = gst_element_factory_find ("nlecomposition");
+  if (!nlecomposition_factory) {
+    GST_ERROR ("The `nlecomposition` object was not found.");
+    if (error)
+      *error = g_error_new (GST_CORE_ERROR, GST_CORE_ERROR_MISSING_PLUGIN,
+          "The `nle` plugin is missing.");
+
+    goto failed;
+  }
+  gst_object_unref (nlecomposition_factory);
+
+
+
   /* register clip classes with the system */
 
   g_type_class_ref (GES_TYPE_TEST_CLIP);
@@ -86,7 +104,9 @@ ges_init_post (GOptionContext * context, GOptionGroup * group, gpointer data,
   g_type_class_ref (GES_TYPE_GROUP);
 
   /* register formatter types with the system */
+#ifndef DISABLE_XPTV
   g_type_class_ref (GES_TYPE_PITIVI_FORMATTER);
+#endif
   g_type_class_ref (GES_TYPE_COMMAND_LINE_FORMATTER);
   g_type_class_ref (GES_TYPE_XML_FORMATTER);
 
@@ -157,7 +177,10 @@ ges_deinit (void)
   g_type_class_unref (g_type_class_peek (GES_TYPE_GROUP));
 
   /* register formatter types with the system */
+#ifndef DISABLE_XPTV
   g_type_class_unref (g_type_class_peek (GES_TYPE_PITIVI_FORMATTER));
+#endif
+
   g_type_class_unref (g_type_class_peek (GES_TYPE_COMMAND_LINE_FORMATTER));
   g_type_class_unref (g_type_class_peek (GES_TYPE_XML_FORMATTER));
 
@@ -298,3 +321,17 @@ ges_init_check (int *argc, char **argv[], GError ** err)
 
   return ges_init ();
 }
+
+/**
+ * ges_is_initialized:
+ *
+ * Use this function to check if GES has been initialized with ges_init()
+ * or ges_init_check().
+ *
+ * Returns: %TRUE if initialization has been done, %FALSE otherwise.
+ */
+gboolean
+ges_is_initialized (void)
+{
+  return ges_initialized;
+}
