@@ -45,8 +45,6 @@ GST_DEBUG_CATEGORY_STATIC (nlecomposition_debug);
 #define _do_init              \
   GST_DEBUG_CATEGORY_INIT (nlecomposition_debug,"nlecomposition", GST_DEBUG_FG_BLUE | GST_DEBUG_BOLD, "GNonLin Composition");
 #define nle_composition_parent_class parent_class
-G_DEFINE_TYPE_WITH_CODE (NleComposition, nle_composition, NLE_TYPE_OBJECT,
-    _do_init);
 
 enum
 {
@@ -165,9 +163,10 @@ struct _NleCompositionPrivate
    *    otherwise, it will be the composition duration.
    */
   GstSegment *segment;
-  GstSegment *outside_segment;
 
-  /* Next running base_time to set on outgoing segment */
+  /* Segment representing the last seek. Simply initialized
+   * segment if no seek occured. */
+  GstSegment *seek_segment;
   guint64 next_base_time;
 
   /*
@@ -208,6 +207,10 @@ static guint _signals[LAST_SIGNAL] = { 0 };
 
 static GParamSpec *nleobject_properties[NLEOBJECT_PROP_LAST];
 
+G_DEFINE_TYPE_WITH_CODE (NleComposition, nle_composition, NLE_TYPE_OBJECT,
+    G_ADD_PRIVATE (NleComposition)
+    _do_init);
+
 #define OBJECT_IN_ACTIVE_SEGMENT(comp,element)      \
   ((NLE_OBJECT_START(element) < comp->priv->current_stack_stop) &&  \
    (NLE_OBJECT_STOP(element) >= comp->priv->current_stack_start))
@@ -546,7 +549,7 @@ _seek_pipeline_func (NleComposition * comp, SeekData * seekd)
 
   gst_segment_do_seek (priv->segment,
       rate, format, flags, cur_type, cur, stop_type, stop, NULL);
-  gst_segment_do_seek (priv->outside_segment,
+  gst_segment_do_seek (priv->seek_segment,
       rate, format, flags, cur_type, cur, stop_type, stop, NULL);
 
   GST_DEBUG_OBJECT (seekd->comp, "Segment now has flags:%d",
@@ -969,8 +972,6 @@ nle_composition_class_init (NleCompositionClass * klass)
   gstbin_class = (GstBinClass *) klass;
   nleobject_class = (NleObjectClass *) klass;
 
-  g_type_class_add_private (klass, sizeof (NleCompositionPrivate));
-
   gst_element_class_set_static_metadata (gstelement_class,
       "GNonLin Composition", "Filter/Editor", "Combines NLE objects",
       "Wim Taymans <wim.taymans@gmail.com>, Edward Hervey <bilboed@bilboed.com>,"
@@ -1043,13 +1044,12 @@ nle_composition_init (NleComposition * comp)
   GST_OBJECT_FLAG_SET (comp, NLE_OBJECT_SOURCE);
   GST_OBJECT_FLAG_SET (comp, NLE_OBJECT_COMPOSITION);
 
-  priv = G_TYPE_INSTANCE_GET_PRIVATE (comp, NLE_TYPE_COMPOSITION,
-      NleCompositionPrivate);
+  priv = nle_composition_get_instance_private (comp);
   priv->objects_start = NULL;
   priv->objects_stop = NULL;
 
   priv->segment = gst_segment_new ();
-  priv->outside_segment = gst_segment_new ();
+  priv->seek_segment = gst_segment_new ();
 
   g_rec_mutex_init (&comp->task_rec_lock);
 
@@ -1140,7 +1140,7 @@ nle_composition_finalize (GObject * object)
   g_hash_table_destroy (priv->objects_hash);
 
   gst_segment_free (priv->segment);
-  gst_segment_free (priv->outside_segment);
+  gst_segment_free (priv->seek_segment);
 
   g_rec_mutex_clear (&comp->task_rec_lock);
 
@@ -1205,7 +1205,7 @@ nle_composition_reset (NleComposition * comp)
   priv->next_base_time = 0;
 
   gst_segment_init (priv->segment, GST_FORMAT_TIME);
-  gst_segment_init (priv->outside_segment, GST_FORMAT_TIME);
+  gst_segment_init (priv->seek_segment, GST_FORMAT_TIME);
 
   if (priv->current)
     g_node_destroy (priv->current);
@@ -1680,8 +1680,8 @@ nle_composition_event_handler (GstPad * ghostpad, GstObject * parent,
           " segment.stop:%" GST_TIME_FORMAT " current_stack_start%"
           GST_TIME_FORMAT " current_stack_stop:%" GST_TIME_FORMAT,
           GST_TIME_ARGS (timestamp),
-          GST_TIME_ARGS (priv->outside_segment->start),
-          GST_TIME_ARGS (priv->outside_segment->stop),
+          GST_TIME_ARGS (priv->seek_segment->start),
+          GST_TIME_ARGS (priv->seek_segment->stop),
           GST_TIME_ARGS (priv->current_stack_start),
           GST_TIME_ARGS (priv->current_stack_stop));
 
@@ -1712,16 +1712,16 @@ nle_composition_event_handler (GstPad * ghostpad, GstObject * parent,
        *
        */
 
-      if (GST_CLOCK_TIME_IS_VALID (priv->outside_segment->start)) {
+      if (GST_CLOCK_TIME_IS_VALID (priv->seek_segment->start)) {
         GstClockTimeDiff curdiff;
 
         /* We'll either create a new event or discard it */
         gst_event_unref (event);
 
         if (priv->segment->rate < 0.0)
-          curdiff = priv->outside_segment->stop - priv->current_stack_stop;
+          curdiff = priv->seek_segment->stop - priv->current_stack_stop;
         else
-          curdiff = priv->current_stack_start - priv->outside_segment->start;
+          curdiff = priv->current_stack_start - priv->seek_segment->start;
         GST_DEBUG ("curdiff %" GST_TIME_FORMAT, GST_TIME_ARGS (curdiff));
         if ((curdiff != 0) && ((timestamp < curdiff)
                 || (curdiff > timestamp + diff))) {
@@ -2455,6 +2455,20 @@ nle_composition_change_state (GstElement * element, GstStateChange transition)
 
   res = GST_ELEMENT_CLASS (parent_class)->change_state (element, transition);
 
+  if (res == GST_STATE_CHANGE_FAILURE) {
+    GST_ERROR_OBJECT (comp, "state change failure %s => %s",
+        gst_element_state_get_name (GST_STATE_TRANSITION_CURRENT (transition)),
+        gst_element_state_get_name (GST_STATE_TRANSITION_NEXT (transition)));
+
+    comp->priv->tearing_down_stack = TRUE;
+    _stop_task (comp);
+    nle_composition_reset (comp);
+    gst_element_set_state (comp->priv->current_bin, GST_STATE_NULL);
+    comp->priv->tearing_down_stack = FALSE;
+
+    return res;
+  }
+
   switch (transition) {
     case GST_STATE_CHANGE_PAUSED_TO_READY:
       comp->priv->tearing_down_stack = FALSE;
@@ -2877,9 +2891,17 @@ _activate_new_stack (NleComposition * comp)
   GST_DEBUG_OBJECT (comp, "New stack activated!");
 
 resync_state:
-  gst_element_set_locked_state (priv->current_bin, FALSE);
+  if (!gst_element_set_locked_state (priv->current_bin, FALSE)) {
+    GST_ERROR_OBJECT (comp, "set locked state failure");
+    return FALSE;
+  }
+
   GST_DEBUG ("going back to parent state");
-  gst_element_sync_state_with_parent (priv->current_bin);
+  if (!gst_element_sync_state_with_parent (priv->current_bin)) {
+    GST_ERROR_OBJECT (comp, "Cannot sync current stack's state");
+    return FALSE;
+  }
+
   GST_DEBUG ("gone back to parent state");
 
   return TRUE;
@@ -2923,6 +2945,43 @@ _set_real_eos_seqnum_from_seek (NleComposition * comp, GstEvent * event)
   return TRUE;
 }
 
+#ifndef GST_DISABLE_GST_DEBUG
+static gboolean
+_print_stack (GNode * node, gpointer res)
+{
+  NleObject *obj = NLE_OBJECT (node->data);
+
+  g_string_append_printf ((GString *) res,
+      "%*s [s=%" GST_TIME_FORMAT " - d=%" GST_TIME_FORMAT "] prio=%d\n",
+      g_node_depth (node) * 4, GST_OBJECT_NAME (obj),
+      GST_TIME_ARGS (NLE_OBJECT_START (obj)),
+      GST_TIME_ARGS (NLE_OBJECT_STOP (obj)), obj->priority);
+
+  return FALSE;
+}
+#endif
+
+static void
+_dump_stack (NleComposition * comp, GNode * stack)
+{
+#ifndef GST_DISABLE_GST_DEBUG
+  GString *res;
+
+  if (gst_debug_category_get_threshold (nlecomposition_debug) < GST_LEVEL_INFO)
+    return;
+
+  res = g_string_new (NULL);
+  g_string_append_printf (res, " ====> dumping stack [%" GST_TIME_FORMAT " - %"
+      GST_TIME_FORMAT "]:\n",
+      GST_TIME_ARGS (comp->priv->current_stack_start),
+      GST_TIME_ARGS (comp->priv->current_stack_stop));
+  g_node_traverse (stack, G_LEVEL_ORDER, G_TRAVERSE_ALL, -1, _print_stack, res);
+
+  GST_INFO_OBJECT (comp, "%s", res->str);
+  g_string_free (res, TRUE);
+#endif
+}
+
 /*
  * update_pipeline:
  * @comp: The #NleComposition
@@ -3026,6 +3085,7 @@ update_pipeline (NleComposition * comp, GstClockTime currenttime, gint32 seqnum,
 
   /* If stacks are different, unlink/relink objects */
   if (!samestack) {
+    _dump_stack (comp, stack);
     _deactivate_stack (comp, _have_to_flush_downstream (update_reason));
     _relink_new_stack (comp, stack, toplevel_seek);
   }
